@@ -44,12 +44,12 @@ namespace KIO { class Job; class ListJob; }
  *
  * Typical usage :
  * @li Create an instance.
- * @li Connect to at least update, clear, newItem, and deleteItem.
+ * @li Connect to at least update, clear, itemsAdded, and itemsDeleted.
  * @li Call openUrl - the signals will be called.
  * @li Reuse the instance when opening a new url (openUrl).
  * @li Destroy the instance when not needed anymore (usually destructor).
  *
- * Advanced usage : call openUrl with _keep = true to list directories
+ * Advanced usage : call openUrl with OpenUrlFlag::Keep to list directories
  * without forgetting the ones previously read (e.g. for a tree view)
  *
  * @author Michael Brade <brade@kde.org>
@@ -100,7 +100,7 @@ public:
    * Run the directory lister on the given url.
    *
    * This method causes KDirLister to emit _all_ the items of @p _url, in any case.
-   * Depending on @p _keep either clear() or clear(const KUrl &) will be
+   * Depending on _flags, either clear() or clear(const KUrl &) will be
    * emitted first.
    *
    * The newItems() signal may be emitted more than once to supply you
@@ -196,7 +196,7 @@ public:
 
   /**
    * Changes the "is viewing dot files" setting.
-   * Calls updateDirectory() if setting changed.
+   * You need to call emitChanges() afterwards.
    * By default this option is disabled (hidden files will not be shown).
    * @param _showDotFiles true to enable showing hidden files, false to
    *        disable
@@ -214,6 +214,7 @@ public:
 
   /**
    * Call this to list only directories.
+   * You need to call emitChanges() afterwards.
    * By default this option is disabled (all files will be shown).
    * @param dirsOnly true to list only directories
    */
@@ -222,7 +223,7 @@ public:
   /**
    * Returns the top level URL that is listed by this KDirLister.
    * It might be different from the one given with openUrl() if there was a
-   * redirection. If you called openUrl() with @p _keep == true this is the
+   * redirection. If you called openUrl() with OpenUrlFlag::Keep this is the
    * first url opened (e.g. in a treeview this is the root).
    *
    * @return the url used by this instance to list the files.
@@ -231,7 +232,7 @@ public:
 
   /**
    * Returns all URLs that are listed by this KDirLister. This is only
-   * useful if you called openUrl() with @p _keep == true, as it happens in a
+   * useful if you called openUrl() with OpenUrlFlag::Keep, as it happens in a
    * treeview, for example. (Note that the base url is included in the list
    * as well, of course.)
    *
@@ -292,6 +293,7 @@ public:
    * You can set more than one filter by separating them with whitespace, e.g
    * "*.cpp *.h".
    * Note: the directory is not automatically reloaded.
+   * You need to call emitChanges() afterwards.
    *
    * @param filter the new filter, QString() to disable filtering
    * @see matchesFilter
@@ -311,6 +313,8 @@ public:
    * NOTE: setting the filter does not automatically reload directory.
    * Also calling this function will not affect any named filter already set.
    *
+   * You need to call emitChanges() afterwards.
+   *
    * @param mimeList a list of mime-types.
    *
    * @see clearMimeFilter
@@ -338,6 +342,8 @@ public:
   /**
    * Clears the mime based filter.
    *
+   * You need to call emitChanges() afterwards.
+   *
    * @see setMimeFilter
    */
   virtual void clearMimeFilter();
@@ -417,7 +423,7 @@ public:
    *
    * @param dir specifies the url for which the items should be returned. This
    *            is only useful if you use KDirLister with multiple URLs
-   *            i.e. using bool keep = true in openUrl().
+   *            i.e. using bool OpenUrlFlag::Keep in openUrl().
    * @param which specifies whether the returned list will contain all entries
    *              or only the ones that passed the nameFilter, mimeFilter, etc.
    *              Note that the latter causes iteration over all the items,
@@ -480,7 +486,7 @@ Q_SIGNALS:
   /**
    * Signal a redirection.
    * Only emitted if there's just one directory to list, i.e. most
-   * probably openUrl() has been called with @p _keep == @p false.
+   * probably openUrl() has been called without OpenUrlFlag::Keep.
    * @param _url the new URL
    */
   void redirection( const KUrl& _url );
@@ -494,7 +500,7 @@ Q_SIGNALS:
 
   /**
    * Signal to clear all items.
-   * It must always be connected to this signal to avoid doubled items!
+   * Make sure to connect to this signal to avoid doubled items.
    */
   void clear();
 
@@ -508,11 +514,20 @@ Q_SIGNALS:
   /**
    * Signal new items.
    *
-   * So use this signal only if you want to modify original KFileItems
    * @param items a list of new items
    */
   void newItems( const KFileItemList& items );
 
+  /**
+   * Signal that new items were found during directory listing.
+   * Alternative signal emitted at the same time as newItems(),
+   * but itemsAdded also passes the url of the parent directory.
+   *
+   * @param items a list of new items
+   * @since 4.2
+   */
+  void itemsAdded(const KUrl& directoryUrl, const KFileItemList& items);
+
   /**
    * Send a list of items filtered-out by mime-type.
    * @param items the list of filtered items
@@ -522,6 +537,8 @@ Q_SIGNALS:
   /**
    * Signals that an item has been deleted
    *
+   * @deprecated Don't connect to this signal. Use itemsDeleted instead.
+   *
    * @param _fileItem the fileItem to delete
    */
   void deleteItem( const KFileItem &_fileItem ); // KDE5: remove, and port to itemsDeleted
